==> gurux_dlms-1.0.72.tar.gz: gurux_dlms-1.0.72/gurux_dlms/objects/enums/ApplicationContextName.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
import sys

#pylint: disable=no-name-in-module
if sys.version_info < (3, 0):
    __base = object
else:
    from enum import IntEnum
    __base = IntEnum

class ApplicationContextName(__base):
    """
    Enumerates application context name.
    """
    #pylint: disable=too-few-public-methods

    #
    # Logical name.
    #
    LOGICAL_NAME = 1
    #
    # Short name.
    #
    SHORT_NAME = 2
    #
    # Logical name with ciphering.
    #
    LOGICAL_NAME_WITH_CIPHERING = 3
    #
    # Short name with ciphering.
    #
    SHORT_NAME_WITH_CIPHERING = 4

==> gurux_dlms-1.0.121.tar.gz: gurux_dlms-1.0.121/gurux_dlms/objects/enums/ApplicationContextName.py <==
#
#  --------------------------------------------------------------------------
#   Gurux Ltd
#
#
#
#  Filename: $HeadURL$
#
#  Version: $Revision$,
#                   $Date$
#                   $Author$
#
#  Copyright (c) Gurux Ltd
#
# ---------------------------------------------------------------------------
#
#   DESCRIPTION
#
#  This file is a part of Gurux Device Framework.
#
#  Gurux Device Framework is Open Source software; you can redistribute it
#  and/or modify it under the terms of the GNU General Public License
#  as published by the Free Software Foundation; version 2 of the License.
#  Gurux Device Framework is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#  See the GNU General Public License for more details.
#
#  More information of Gurux products: http://www.gurux.org
#
#  This code is licensed under the GNU General Public License v2.
#  Full text may be retrieved at http://www.gnu.org/licenses/gpl-2.0.txt
# ---------------------------------------------------------------------------
from gurux_dlms.GXIntEnum import GXIntEnum

class ApplicationContextName(GXIntEnum):
    """
    Enumerates application context name.
    """
    #pylint: disable=too-few-public-methods

    #
    # Logical name.
    #
    LOGICAL_NAME = 1
    #
    # Short name.
    #
    SHORT_NAME = 2
    #
    # Logical name with ciphering.
    #
    LOGICAL_NAME_WITH_CIPHERING = 3
    #
    # Short name with ciphering.
    #
    SHORT_NAME_WITH_CIPHERING = 4
